@@ -13,7 +13,7 @@ mod yaml;
 #[cfg(feature = "toml")]
 pub use self::toml::parse_toml;
 #[cfg(feature = "json")]
-pub use json::parse_json;
+pub use json::{parse_json, parse_json5};
 pub use systems::SYSTEM_SYMBOLS;
 #[cfg(feature = "yaml")]
 pub use yaml::parse_yaml;
